@@ -364,7 +364,7 @@ int fetch_request(t_session *session) {
 							*strend = '\0';
 							content_length = str2int(strstart);
 							*strend = '\r';
-							if (content_length == -1) {
+							if (content_length < 0) {
 								result = 400;
 								break;
 							}
@@ -570,11 +570,6 @@ int parse_request(t_session *session, int total_bytes) {
 	if ((session->request_uri = strdup(session->uri)) == NULL) {
 		return -1;
 	}
-	if (session->host->secure_url) {
-		if (strstr(session->request_uri, "%00") != NULL) {
-			return 403;
-		}
-	}
 
 	/* Protocol version
 	 */
@@ -815,6 +810,12 @@ int serve_client(t_session *session) {
 		return result;
 	}
 
+	if (session->host->secure_url) {
+		if (strstr(session->request_uri, "%00") != NULL) {
+			return 403;
+		}
+	}
+
 	if (session->request_method == TRACE) {
 		if (session->binding->enable_trace == false) {
 			return 501;
