@@ -221,28 +221,40 @@ int ssl_receive(SSL *ssl, char *buffer, unsigned int maxlength) {
 	int result;
 
 	result = SSL_read(ssl, buffer, maxlength);
-#ifdef DEBUG
-	if (result < 0) {
-		fprintf(stderr, "SSL_read(): ");
-		print_ssl_error(ssl, result);
+	if (result > 0) {
+		return result;
+	} else if (result == 0) {
+		if (SSL_get_error(ssl, result) == SSL_ERROR_ZERO_RETURN) {
+			return 0;
+		}
 	}
-#endif
 
-	return result;
+#ifdef DEBUG
+	fprintf(stderr, "SSL_read(): ");
+	print_ssl_error(ssl, result);
+#endif	
+
+	return -1;
 }
 
 int ssl_send(SSL *ssl, char *buffer, unsigned int length) {
 	int result;
 	
 	result = SSL_write(ssl, buffer, length);
-#ifdef DEBUG
-	if (result < 0) {
-		fprintf(stderr, "SSL_write(): ");
-		print_ssl_error(ssl, result);
+	if (result > 0) {
+		return result;
+	} else if (result == 0) {
+		if (SSL_get_error(ssl, result) == SSL_ERROR_ZERO_RETURN) {
+			return 0;
+		}
 	}
+
+#ifdef DEBUG
+	fprintf(stderr, "SSL_write(): ");
+	print_ssl_error(ssl, result);
 #endif
 
-	return result;
+	return -1;
 }
 
 int ssl_close(SSL **ssl) {
