@@ -6,6 +6,7 @@
 #include "libstr.h"
 #include "mimetype.h"
 
+#define MAX_LINE_LENGTH 256
 #define MAX_EXT 6
 
 static char *default_mimetype = "text/plain";
@@ -14,7 +15,7 @@ static char *default_mimetype = "text/plain";
  */
 int read_mimetypes(char *configfile, t_mimetype **mime) {
 	FILE *fp;
-	char line[257], *data, *next, *ext;
+	char line[MAX_LINE_LENGTH + 1], *data, *next, *ext;
 	bool quit;
 	t_mimename *w_mime = NULL;
 	t_extension *w_ext = NULL;
@@ -28,16 +29,16 @@ int read_mimetypes(char *configfile, t_mimetype **mime) {
 		fclose(fp);
 		return -1;
 	}
-	line[256] = '\0';
+	line[MAX_LINE_LENGTH] = '\0';
 
-	while (fgets(line, 256, fp) != NULL) {
+	while (fgets(line, MAX_LINE_LENGTH, fp) != NULL) {
 		if ((next = data = strdup(line)) == NULL) {
 			return -1;
 		}
 		while (*next != '\0') {
 			if (*next == '\t') {
 				*next = ' ';
-			} else if (*next == '\n') {
+			} else if ((*next == '\r') || (*next == '\n')) {
 				*next = '\0';
 			}
 			next++;
