@@ -304,6 +304,12 @@ static int fgets_multi(char *line, int size, FILE *fp) {
 		return -1;
 	} else if (fgets(line, size, fp) != NULL) {
 		if ((pos = strstr(line, " \\\n")) == NULL) {
+#ifdef CYGWIN
+			pos = strstr(line, " \\\r");
+		}
+
+		if (pos == NULL) {
+#endif
 			lines = 0;
 		} else if ((lines = fgets_multi(pos, size - (pos - line), fp)) == -1) {
 			return -1;
@@ -509,6 +515,7 @@ int check_configuration(t_config *config) {
 	t_connect_to *connect_to;
 	t_host *host;
 	char c;
+	int i;
 #ifdef HAVE_SSL
 	t_binding *binding;
 
@@ -540,6 +547,12 @@ int check_configuration(t_config *config) {
 
 	host = config->first_host;
 	while (host != NULL) {
+		for (i = 0; i < host->hostname.size; i++) {
+			if (strchr(*(host->hostname.item + i), '/') != NULL) {
+				fprintf(stderr, "The hostname '%s' contains a path.\n", *(host->hostname.item + i));
+				return -1;
+			}
+		}
 		if ((host->wrap_cgi != NULL) && (host->fast_cgi.size != 0)) {
 			fprintf(stderr, "The host '%s' contains both a WrapCGI and FastCGI option.\n", *(host->hostname.item));
 			return -1;
@@ -601,7 +614,7 @@ int check_configuration(t_config *config) {
 #ifdef HAVE_SSL
 			"RequireSSL and "
 #endif
-			"RequiredBinding not allowed outside VirutalHost block.\n");
+			"RequiredBinding not allowed outside VirtualHost section.\n");
 		return -1;
 	}
 
@@ -1575,24 +1588,22 @@ int read_main_configfile(char *configfile, t_config *config, bool config_check)
 						}
 						break;
 					case fcgi_server:
-						if ((config->fcgi_server->fcgi_id != NULL) && (config->fcgi_server->connect_to->port != 0)) {
+						if ((config->fcgi_server->fcgi_id != NULL) && (config->fcgi_server->connect_to != NULL) && (config->fcgi_server->extension.size > 0)) {
 							current_fcgi_server = NULL;
 						} else {
-							fprintf(stderr, "A FastCGIid and/or ConnectTo is missing in a FastCGIserver section in %s.\n", configfile);
+							fprintf(stderr, "A FastCGIid, Extension or ConnectTo is missing in a FastCGIserver section in %s.\n", configfile);
 							retval = -1;
 						}
 						break;
 					case virtual_host:
-						if (current_host->hostname.size > 0) {
-							if (current_host->website_root == NULL) {
-								fprintf(stderr, "A WebsiteRoot is missing for %s in %s\n", current_host->hostname.item[0], configfile);
-								retval = -1;
-							} else {
-								current_host = config->first_host;
-							}
-						} else {
+						if (current_host->hostname.size == 0) {
 							fprintf(stderr, "A Hostname is missing in a VirtualHost section in %s\n", configfile);
 							retval = -1;
+						} else if (current_host->website_root == NULL) {
+							fprintf(stderr, "A WebsiteRoot is missing for %s in %s\n", current_host->hostname.item[0], configfile);
+							retval = -1;
+						} else {
+							current_host = config->first_host;
 						}
 						break;
 #ifdef HAVE_REWRITE
