@@ -145,11 +145,36 @@ int read_directory(char *dir, t_line **config, t_line **aliases) {
 	return retval;
 }
 
+static int fgets_multi(char *line, int size, FILE *fp) {
+	int lines;
+	char *pos;
+
+	if ((line == NULL) || (size <= 1)) {
+		return -1;
+	} else if (fgets(line, size, fp) != NULL) {
+		if ((pos = strstr(line, " \\\n")) == NULL) {
+#ifdef CYGWIN
+			pos = strstr(line, " \\\r");
+		}
+
+		if (pos == NULL) {
+#endif
+			lines = 0;
+		} else if ((lines = fgets_multi(pos, size - (pos - line), fp)) == -1) {
+			return -1;
+		}
+		return 1 + lines;
+	} else {
+		return 0;
+	}
+}
+
+
 int read_file(char *config_file, t_line **config, t_line **aliases, bool handle_include) {
 	FILE *fp;
 	char line[MAX_INPUT_SIZE + 1], *data, *value;
 	bool is_alias;
-	int linenr = 0, retval = 0;
+	int lines_read, linenr = 0, retval = 0;
 
 	if (quiet == false) {
 		printf("Reading %s\n", config_file);
@@ -161,8 +186,13 @@ int read_file(char *config_file, t_line **config, t_line **aliases, bool handle_
 	}
 
 	line[MAX_INPUT_SIZE] = '\0';
-	while (fgets(line, MAX_INPUT_SIZE, fp) != NULL) {
-		linenr++;
+	while ((lines_read = fgets_multi(line, MAX_INPUT_SIZE, fp)) != 0) {
+		if ((lines_read == -1) || (strlen(line) > MAX_INPUT_SIZE)) {
+			fprintf(stderr, "Line %d in %s is too long.\n", linenr, config_file);
+			return -1;
+		}
+
+		linenr += lines_read;
 		data = strip_line(line);
 		if ((data[0] == '#') || (data[0] == '\0')) {
 			continue;
